from ..broker import Broker


class SwitchFwdNeighborBroker(Broker):
    controller = "switch_fwd_neighbors"

    def show(self, **kwargs):
        """Shows the details for the specified switch fwd neighbor.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
             :type NeighborID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of switch fwd neighbor methods. The listed methods will be called on each switch fwd neighbor returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return switch_fwd_neighbor: The switch fwd neighbor identified by the specified NeighborID.
             :rtype switch_fwd_neighbor: SwitchFwdNeighbor

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available switch fwd neighbors. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
             :type NeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
             :type NeighborID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMAC: The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship.
             :type SwitchFwdNeighborMAC: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMAC: The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship.
             :type SwitchFwdNeighborMAC: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the switch fwd neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of switch fwd neighbor methods. The listed methods will be called on each switch fwd neighbor returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` NeighborID

             :param sort: The data field(s) to use for sorting the output. Default is NeighborID. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SwitchFwdNeighbor. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return switch_fwd_neighbors: An array of the SwitchFwdNeighbor objects that match the specified input criteria.
             :rtype switch_fwd_neighbors: Array of SwitchFwdNeighbor

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available switch fwd neighbors matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
             :type NeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
             :type NeighborID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type SwitchFwdNeighborChangedCols: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type SwitchFwdNeighborChangedCols: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type SwitchFwdNeighborEndTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type SwitchFwdNeighborEndTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborFirstSeenTime: The date and time this switch forwarding neighbor was first seen on the network, and since which it has been continuously present.
             :type SwitchFwdNeighborFirstSeenTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborFirstSeenTime: The date and time this switch forwarding neighbor was first seen on the network, and since which it has been continuously present.
             :type SwitchFwdNeighborFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborIPDotted: The IP address corresponding to the MAC found in the switch forwarding table, in dotted (or colon-delimited for IPv6) format.
             :type SwitchFwdNeighborIPDotted: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborIPDotted: The IP address corresponding to the MAC found in the switch forwarding table, in dotted (or colon-delimited for IPv6) format.
             :type SwitchFwdNeighborIPDotted: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborIPNumeric: The numerical value of the IP address corresponding to the MAC found in the switch forwarding table.
             :type SwitchFwdNeighborIPNumeric: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborIPNumeric: The numerical value of the IP address corresponding to the MAC found in the switch forwarding table.
             :type SwitchFwdNeighborIPNumeric: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMAC: The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship.
             :type SwitchFwdNeighborMAC: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMAC: The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship.
             :type SwitchFwdNeighborMAC: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMapSource: Internal tracking information for NetMRI algorithms.
             :type SwitchFwdNeighborMapSource: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborMapSource: Internal tracking information for NetMRI algorithms.
             :type SwitchFwdNeighborMapSource: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborStartTime: The starting effective time of this revision of the record.
             :type SwitchFwdNeighborStartTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborStartTime: The starting effective time of this revision of the record.
             :type SwitchFwdNeighborStartTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborTimestamp: The date and time this record was collected or calculated.
             :type SwitchFwdNeighborTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborTimestamp: The date and time this record was collected or calculated.
             :type SwitchFwdNeighborTimestamp: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborType: Internal tracking information for NetMRI algorithms.
             :type SwitchFwdNeighborType: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborType: Internal tracking information for NetMRI algorithms.
             :type SwitchFwdNeighborType: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborVlanID: The internal NetMRI identifier for the VLAN of this neighbor.
             :type SwitchFwdNeighborVlanID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborVlanID: The internal NetMRI identifier for the VLAN of this neighbor.
             :type SwitchFwdNeighborVlanID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborVlanIndex: The numerical VLAN number (VLAN ID) of this neighbor.
             :type SwitchFwdNeighborVlanIndex: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchFwdNeighborVlanIndex: The numerical VLAN number (VLAN ID) of this neighbor.
             :type SwitchFwdNeighborVlanIndex: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the switch fwd neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of switch fwd neighbor methods. The listed methods will be called on each switch fwd neighbor returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` NeighborID

             :param sort: The data field(s) to use for sorting the output. Default is NeighborID. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SwitchFwdNeighbor. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against switch fwd neighbors, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, NeighborID, SwitchFwdNeighborChangedCols, SwitchFwdNeighborEndTime, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborMAC, SwitchFwdNeighborMapSource, SwitchFwdNeighborStartTime, SwitchFwdNeighborTimestamp, SwitchFwdNeighborType, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return switch_fwd_neighbors: An array of the SwitchFwdNeighbor objects that match the specified input criteria.
             :rtype switch_fwd_neighbors: Array of SwitchFwdNeighbor

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available switch fwd neighbors matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, NeighborID, SwitchFwdNeighborChangedCols, SwitchFwdNeighborEndTime, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborMAC, SwitchFwdNeighborMapSource, SwitchFwdNeighborStartTime, SwitchFwdNeighborTimestamp, SwitchFwdNeighborType, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NeighborID: The operator to apply to the field NeighborID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NeighborID: The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NeighborID: If op_NeighborID is specified, the field named in this input will be compared to the value in NeighborID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NeighborID must be specified if op_NeighborID is specified.
             :type val_f_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NeighborID: If op_NeighborID is specified, this value will be compared to the value in NeighborID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NeighborID must be specified if op_NeighborID is specified.
             :type val_c_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborChangedCols: The operator to apply to the field SwitchFwdNeighborChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborChangedCols: If op_SwitchFwdNeighborChangedCols is specified, the field named in this input will be compared to the value in SwitchFwdNeighborChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborChangedCols must be specified if op_SwitchFwdNeighborChangedCols is specified.
             :type val_f_SwitchFwdNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborChangedCols: If op_SwitchFwdNeighborChangedCols is specified, this value will be compared to the value in SwitchFwdNeighborChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborChangedCols must be specified if op_SwitchFwdNeighborChangedCols is specified.
             :type val_c_SwitchFwdNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborEndTime: The operator to apply to the field SwitchFwdNeighborEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborEndTime: If op_SwitchFwdNeighborEndTime is specified, the field named in this input will be compared to the value in SwitchFwdNeighborEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborEndTime must be specified if op_SwitchFwdNeighborEndTime is specified.
             :type val_f_SwitchFwdNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborEndTime: If op_SwitchFwdNeighborEndTime is specified, this value will be compared to the value in SwitchFwdNeighborEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborEndTime must be specified if op_SwitchFwdNeighborEndTime is specified.
             :type val_c_SwitchFwdNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborFirstSeenTime: The operator to apply to the field SwitchFwdNeighborFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborFirstSeenTime: The date and time this switch forwarding neighbor was first seen on the network, and since which it has been continuously present. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborFirstSeenTime: If op_SwitchFwdNeighborFirstSeenTime is specified, the field named in this input will be compared to the value in SwitchFwdNeighborFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborFirstSeenTime must be specified if op_SwitchFwdNeighborFirstSeenTime is specified.
             :type val_f_SwitchFwdNeighborFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborFirstSeenTime: If op_SwitchFwdNeighborFirstSeenTime is specified, this value will be compared to the value in SwitchFwdNeighborFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborFirstSeenTime must be specified if op_SwitchFwdNeighborFirstSeenTime is specified.
             :type val_c_SwitchFwdNeighborFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborIPDotted: The operator to apply to the field SwitchFwdNeighborIPDotted. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborIPDotted: The IP address corresponding to the MAC found in the switch forwarding table, in dotted (or colon-delimited for IPv6) format. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborIPDotted: If op_SwitchFwdNeighborIPDotted is specified, the field named in this input will be compared to the value in SwitchFwdNeighborIPDotted using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborIPDotted must be specified if op_SwitchFwdNeighborIPDotted is specified.
             :type val_f_SwitchFwdNeighborIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborIPDotted: If op_SwitchFwdNeighborIPDotted is specified, this value will be compared to the value in SwitchFwdNeighborIPDotted using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborIPDotted must be specified if op_SwitchFwdNeighborIPDotted is specified.
             :type val_c_SwitchFwdNeighborIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborIPNumeric: The operator to apply to the field SwitchFwdNeighborIPNumeric. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborIPNumeric: The numerical value of the IP address corresponding to the MAC found in the switch forwarding table. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborIPNumeric: If op_SwitchFwdNeighborIPNumeric is specified, the field named in this input will be compared to the value in SwitchFwdNeighborIPNumeric using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborIPNumeric must be specified if op_SwitchFwdNeighborIPNumeric is specified.
             :type val_f_SwitchFwdNeighborIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborIPNumeric: If op_SwitchFwdNeighborIPNumeric is specified, this value will be compared to the value in SwitchFwdNeighborIPNumeric using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborIPNumeric must be specified if op_SwitchFwdNeighborIPNumeric is specified.
             :type val_c_SwitchFwdNeighborIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborMAC: The operator to apply to the field SwitchFwdNeighborMAC. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborMAC: The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborMAC: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborMAC: If op_SwitchFwdNeighborMAC is specified, the field named in this input will be compared to the value in SwitchFwdNeighborMAC using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborMAC must be specified if op_SwitchFwdNeighborMAC is specified.
             :type val_f_SwitchFwdNeighborMAC: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborMAC: If op_SwitchFwdNeighborMAC is specified, this value will be compared to the value in SwitchFwdNeighborMAC using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborMAC must be specified if op_SwitchFwdNeighborMAC is specified.
             :type val_c_SwitchFwdNeighborMAC: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborMapSource: The operator to apply to the field SwitchFwdNeighborMapSource. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborMapSource: Internal tracking information for NetMRI algorithms. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborMapSource: If op_SwitchFwdNeighborMapSource is specified, the field named in this input will be compared to the value in SwitchFwdNeighborMapSource using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborMapSource must be specified if op_SwitchFwdNeighborMapSource is specified.
             :type val_f_SwitchFwdNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborMapSource: If op_SwitchFwdNeighborMapSource is specified, this value will be compared to the value in SwitchFwdNeighborMapSource using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborMapSource must be specified if op_SwitchFwdNeighborMapSource is specified.
             :type val_c_SwitchFwdNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborStartTime: The operator to apply to the field SwitchFwdNeighborStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborStartTime: The starting effective time of this revision of the record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborStartTime: If op_SwitchFwdNeighborStartTime is specified, the field named in this input will be compared to the value in SwitchFwdNeighborStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborStartTime must be specified if op_SwitchFwdNeighborStartTime is specified.
             :type val_f_SwitchFwdNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborStartTime: If op_SwitchFwdNeighborStartTime is specified, this value will be compared to the value in SwitchFwdNeighborStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborStartTime must be specified if op_SwitchFwdNeighborStartTime is specified.
             :type val_c_SwitchFwdNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborTimestamp: The operator to apply to the field SwitchFwdNeighborTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborTimestamp: If op_SwitchFwdNeighborTimestamp is specified, the field named in this input will be compared to the value in SwitchFwdNeighborTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborTimestamp must be specified if op_SwitchFwdNeighborTimestamp is specified.
             :type val_f_SwitchFwdNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborTimestamp: If op_SwitchFwdNeighborTimestamp is specified, this value will be compared to the value in SwitchFwdNeighborTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborTimestamp must be specified if op_SwitchFwdNeighborTimestamp is specified.
             :type val_c_SwitchFwdNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborType: The operator to apply to the field SwitchFwdNeighborType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborType: Internal tracking information for NetMRI algorithms. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborType: If op_SwitchFwdNeighborType is specified, the field named in this input will be compared to the value in SwitchFwdNeighborType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborType must be specified if op_SwitchFwdNeighborType is specified.
             :type val_f_SwitchFwdNeighborType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborType: If op_SwitchFwdNeighborType is specified, this value will be compared to the value in SwitchFwdNeighborType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborType must be specified if op_SwitchFwdNeighborType is specified.
             :type val_c_SwitchFwdNeighborType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborVlanID: The operator to apply to the field SwitchFwdNeighborVlanID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborVlanID: The internal NetMRI identifier for the VLAN of this neighbor. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborVlanID: If op_SwitchFwdNeighborVlanID is specified, the field named in this input will be compared to the value in SwitchFwdNeighborVlanID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborVlanID must be specified if op_SwitchFwdNeighborVlanID is specified.
             :type val_f_SwitchFwdNeighborVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborVlanID: If op_SwitchFwdNeighborVlanID is specified, this value will be compared to the value in SwitchFwdNeighborVlanID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborVlanID must be specified if op_SwitchFwdNeighborVlanID is specified.
             :type val_c_SwitchFwdNeighborVlanID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SwitchFwdNeighborVlanIndex: The operator to apply to the field SwitchFwdNeighborVlanIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SwitchFwdNeighborVlanIndex: The numerical VLAN number (VLAN ID) of this neighbor. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SwitchFwdNeighborVlanIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SwitchFwdNeighborVlanIndex: If op_SwitchFwdNeighborVlanIndex is specified, the field named in this input will be compared to the value in SwitchFwdNeighborVlanIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SwitchFwdNeighborVlanIndex must be specified if op_SwitchFwdNeighborVlanIndex is specified.
             :type val_f_SwitchFwdNeighborVlanIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SwitchFwdNeighborVlanIndex: If op_SwitchFwdNeighborVlanIndex is specified, this value will be compared to the value in SwitchFwdNeighborVlanIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SwitchFwdNeighborVlanIndex must be specified if op_SwitchFwdNeighborVlanIndex is specified.
             :type val_c_SwitchFwdNeighborVlanIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the switch fwd neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of switch fwd neighbor methods. The listed methods will be called on each switch fwd neighbor returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` NeighborID

             :param sort: The data field(s) to use for sorting the output. Default is NeighborID. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SwitchFwdNeighbor. Valid values are DataSourceID, NeighborID, SwitchFwdNeighborFirstSeenTime, SwitchFwdNeighborStartTime, SwitchFwdNeighborEndTime, SwitchFwdNeighborChangedCols, SwitchFwdNeighborTimestamp, SwitchFwdNeighborMapSource, SwitchFwdNeighborType, SwitchFwdNeighborMAC, SwitchFwdNeighborIPDotted, SwitchFwdNeighborIPNumeric, SwitchFwdNeighborVlanID, SwitchFwdNeighborVlanIndex. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return switch_fwd_neighbors: An array of the SwitchFwdNeighbor objects that match the specified input criteria.
             :rtype switch_fwd_neighbors: Array of SwitchFwdNeighbor

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..remote import RemoteModel


class ReportJobSpecificationGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``name:`` none
    |  ``attribute type:`` string

    |  ``reportname:`` none
    |  ``attribute type:`` string

    |  ``file_name:`` none
    |  ``attribute type:`` string

    |  ``created_by:`` none
    |  ``attribute type:`` string

    |  ``schedule_json:`` none
    |  ``attribute type:`` string

    |  ``schedule:`` none
    |  ``attribute type:`` string

    |  ``recipients:`` none
    |  ``attribute type:`` string

    |  ``last_run:`` none
    |  ``attribute type:`` string

    |  ``is_removed:`` none
    |  ``attribute type:`` string

    |  ``origid:`` none
    |  ``attribute type:`` string

    |  ``auth_users:`` none
    |  ``attribute type:`` string

    |  ``report_id:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "name",
                  "reportname",
                  "file_name",
                  "created_by",
                  "schedule_json",
                  "schedule",
                  "recipients",
                  "last_run",
                  "is_removed",
                  "origid",
                  "auth_users",
                  "report_id",
                  )



from ..remote import RemoteModel


class DiscoveryHintRemote(RemoteModel):
    """
    Discovery hints used by the NetMRI discovery engine.


    |  ``id:`` The internal NetMRI identifier for the discovery hint.
    |  ``attribute type:`` number

    |  ``hint:`` The hint used the by discovery engine.
    |  ``attribute type:`` string

    |  ``device_type:`` The device type applied to the given discovery hint.
    |  ``attribute type:`` string

    |  ``UnitID:`` The internal NetMRI identifier collector assigned to the discovery hint.
    |  ``attribute type:`` number

    |  ``created_by:`` The user that initially created the discovery hint.
    |  ``attribute type:`` string

    |  ``updated_by:`` The user that last updated the discovery hint.
    |  ``attribute type:`` string

    |  ``created_at:`` The date and time the hint was created.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the hint was last modified.
    |  ``attribute type:`` datetime

    |  ``cli_user_name_secure:`` The user name for the device.
    |  ``attribute type:`` string

    |  ``cli_user_password_secure:`` The password for the device.
    |  ``attribute type:`` string

    |  ``snmp_protocol:`` The SNMP protocol for which to use these credentials.
    |  ``attribute type:`` string

    |  ``snmp_community_secure:`` The SNMP community string.
    |  ``attribute type:`` string

    |  ``snmp_auth_protocol:`` The SNMPv3 authentication protocol to use with this credential.
    |  ``attribute type:`` string

    |  ``snmp_auth_password_secure:`` The SNMPv3 authentication protocol password
    |  ``attribute type:`` string

    |  ``snmp_private_protocol:`` The SNMPv3 privacy protocol to use with this credential.
    |  ``attribute type:`` string

    |  ``snmp_private_password_secure:`` The SNMPv3 privacy protocol password.
    |  ``attribute type:`` string

    |  ``secure_version:`` The encryption version of the username and passwords.
    |  ``attribute type:`` number

    |  ``cli_user_name_secure_ssh:`` Device specific CLI username for ssh protocol.
    |  ``attribute type:`` string

    |  ``cli_user_password_secure_ssh:`` Device specific CLI password for ssh protocol.
    |  ``attribute type:`` string

    |  ``cli_user_name_secure_telnet:`` Device specific CLI username for telnet protocol.
    |  ``attribute type:`` string

    |  ``cli_user_password_secure_telnet:`` Device specific CLI password for telnet protocol.
    |  ``attribute type:`` string

    |  ``cli_enable_password_secure:`` Device specific CLI enable password for all protocols.
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "hint",
                  "device_type",
                  "UnitID",
                  "created_by",
                  "updated_by",
                  "created_at",
                  "updated_at",
                  "cli_user_name_secure",
                  "cli_user_password_secure",
                  "snmp_protocol",
                  "snmp_community_secure",
                  "snmp_auth_protocol",
                  "snmp_auth_password_secure",
                  "snmp_private_protocol",
                  "snmp_private_password_secure",
                  "secure_version",
                  "cli_user_name_secure_ssh",
                  "cli_user_password_secure_ssh",
                  "cli_user_name_secure_telnet",
                  "cli_user_password_secure_telnet",
                  "cli_enable_password_secure",
                  )



from ..broker import Broker


class PartitionCalendarBroker(Broker):
    controller = "partition_calendar"

    def get_minimal_date(self, **kwargs):
        """Returns minimal calendar date.

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("get_minimal_date"), kwargs)



from ..broker import Broker


class DeviceFilterSetBroker(Broker):
    controller = "device_filter_sets"

    def show(self, **kwargs):
        """Shows the details for the specified device filter set.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFilterSetID: The internal NetMRI identifier for this rule list.
             :type DeviceFilterSetID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device filter set methods. The listed methods will be called on each device filter set returned and included in the output. Available methods are: data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_filter_set: The device filter set identified by the specified DeviceFilterSetID.
             :rtype device_filter_set: DeviceFilterSet

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device filter sets. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceFilterSetID: The internal NetMRI identifier for this rule list.
             :type DeviceFilterSetID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which this rule list belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device filter sets as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device filter set methods. The listed methods will be called on each device filter set returned and included in the output. Available methods are: data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFilterSetID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFilterSetID. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFilterSet. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_filter_sets: An array of the DeviceFilterSet objects that match the specified input criteria.
             :rtype device_filter_sets: Array of DeviceFilterSet

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device filter sets matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceFilterSetID: The internal NetMRI identifier for this rule list.
             :type DeviceFilterSetID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which this rule list belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetArtificialInd: A flag indicating that this rule list has no counterpart in the device configuration.
             :type FltSetArtificialInd: Array of Boolean

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type FltSetChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetConfigText: The original text of the definition of this rule list in the device configuration.
             :type FltSetConfigText: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetEndTime: The ending effective time of this record, or empty if still in effect.
             :type FltSetEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetFirstSeenTime: The timestamp of when NetMRI first discovered this rule list.
             :type FltSetFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetIPVersion: the IP version of the packets filtered by this rule list - default is 4.
             :type FltSetIPVersion: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetName: The name of this rule-list.
             :type FltSetName: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetProvisionData: Internal data - do not modify, may change without warning.
             :type FltSetProvisionData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetStartTime: The starting effective time of this record.
             :type FltSetStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetTimestamp: The date and time this record was collected or calculated.
             :type FltSetTimestamp: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FltSetUseCount: The number of usage of this rule list inside the configuration (may be for filtering or for NAT, vpn etc).
             :type FltSetUseCount: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device filter sets as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device filter set methods. The listed methods will be called on each device filter set returned and included in the output. Available methods are: data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFilterSetID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFilterSetID. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFilterSet. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device filter sets, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceFilterSetID, DeviceID, FltSetArtificialInd, FltSetChangedCols, FltSetConfigText, FltSetEndTime, FltSetFirstSeenTime, FltSetIPVersion, FltSetName, FltSetProvisionData, FltSetStartTime, FltSetTimestamp, FltSetUseCount.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_filter_sets: An array of the DeviceFilterSet objects that match the specified input criteria.
             :rtype device_filter_sets: Array of DeviceFilterSet

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device filter sets matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceFilterSetID, DeviceID, FltSetArtificialInd, FltSetChangedCols, FltSetConfigText, FltSetEndTime, FltSetFirstSeenTime, FltSetIPVersion, FltSetName, FltSetProvisionData, FltSetStartTime, FltSetTimestamp, FltSetUseCount.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceFilterSetID: The operator to apply to the field DeviceFilterSetID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceFilterSetID: The internal NetMRI identifier for this rule list. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceFilterSetID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceFilterSetID: If op_DeviceFilterSetID is specified, the field named in this input will be compared to the value in DeviceFilterSetID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceFilterSetID must be specified if op_DeviceFilterSetID is specified.
             :type val_f_DeviceFilterSetID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceFilterSetID: If op_DeviceFilterSetID is specified, this value will be compared to the value in DeviceFilterSetID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceFilterSetID must be specified if op_DeviceFilterSetID is specified.
             :type val_c_DeviceFilterSetID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device to which this rule list belongs. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetArtificialInd: The operator to apply to the field FltSetArtificialInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetArtificialInd: A flag indicating that this rule list has no counterpart in the device configuration. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetArtificialInd: If op_FltSetArtificialInd is specified, the field named in this input will be compared to the value in FltSetArtificialInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetArtificialInd must be specified if op_FltSetArtificialInd is specified.
             :type val_f_FltSetArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetArtificialInd: If op_FltSetArtificialInd is specified, this value will be compared to the value in FltSetArtificialInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetArtificialInd must be specified if op_FltSetArtificialInd is specified.
             :type val_c_FltSetArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetChangedCols: The operator to apply to the field FltSetChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetChangedCols: If op_FltSetChangedCols is specified, the field named in this input will be compared to the value in FltSetChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetChangedCols must be specified if op_FltSetChangedCols is specified.
             :type val_f_FltSetChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetChangedCols: If op_FltSetChangedCols is specified, this value will be compared to the value in FltSetChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetChangedCols must be specified if op_FltSetChangedCols is specified.
             :type val_c_FltSetChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetConfigText: The operator to apply to the field FltSetConfigText. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetConfigText: The original text of the definition of this rule list in the device configuration. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetConfigText: If op_FltSetConfigText is specified, the field named in this input will be compared to the value in FltSetConfigText using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetConfigText must be specified if op_FltSetConfigText is specified.
             :type val_f_FltSetConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetConfigText: If op_FltSetConfigText is specified, this value will be compared to the value in FltSetConfigText using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetConfigText must be specified if op_FltSetConfigText is specified.
             :type val_c_FltSetConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetEndTime: The operator to apply to the field FltSetEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetEndTime: If op_FltSetEndTime is specified, the field named in this input will be compared to the value in FltSetEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetEndTime must be specified if op_FltSetEndTime is specified.
             :type val_f_FltSetEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetEndTime: If op_FltSetEndTime is specified, this value will be compared to the value in FltSetEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetEndTime must be specified if op_FltSetEndTime is specified.
             :type val_c_FltSetEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetFirstSeenTime: The operator to apply to the field FltSetFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetFirstSeenTime: The timestamp of when NetMRI first discovered this rule list. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetFirstSeenTime: If op_FltSetFirstSeenTime is specified, the field named in this input will be compared to the value in FltSetFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetFirstSeenTime must be specified if op_FltSetFirstSeenTime is specified.
             :type val_f_FltSetFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetFirstSeenTime: If op_FltSetFirstSeenTime is specified, this value will be compared to the value in FltSetFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetFirstSeenTime must be specified if op_FltSetFirstSeenTime is specified.
             :type val_c_FltSetFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetIPVersion: The operator to apply to the field FltSetIPVersion. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetIPVersion: the IP version of the packets filtered by this rule list - default is 4. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetIPVersion: If op_FltSetIPVersion is specified, the field named in this input will be compared to the value in FltSetIPVersion using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetIPVersion must be specified if op_FltSetIPVersion is specified.
             :type val_f_FltSetIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetIPVersion: If op_FltSetIPVersion is specified, this value will be compared to the value in FltSetIPVersion using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetIPVersion must be specified if op_FltSetIPVersion is specified.
             :type val_c_FltSetIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetName: The operator to apply to the field FltSetName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetName: The name of this rule-list. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetName: If op_FltSetName is specified, the field named in this input will be compared to the value in FltSetName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetName must be specified if op_FltSetName is specified.
             :type val_f_FltSetName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetName: If op_FltSetName is specified, this value will be compared to the value in FltSetName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetName must be specified if op_FltSetName is specified.
             :type val_c_FltSetName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetProvisionData: The operator to apply to the field FltSetProvisionData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetProvisionData: Internal data - do not modify, may change without warning. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetProvisionData: If op_FltSetProvisionData is specified, the field named in this input will be compared to the value in FltSetProvisionData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetProvisionData must be specified if op_FltSetProvisionData is specified.
             :type val_f_FltSetProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetProvisionData: If op_FltSetProvisionData is specified, this value will be compared to the value in FltSetProvisionData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetProvisionData must be specified if op_FltSetProvisionData is specified.
             :type val_c_FltSetProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetStartTime: The operator to apply to the field FltSetStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetStartTime: If op_FltSetStartTime is specified, the field named in this input will be compared to the value in FltSetStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetStartTime must be specified if op_FltSetStartTime is specified.
             :type val_f_FltSetStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetStartTime: If op_FltSetStartTime is specified, this value will be compared to the value in FltSetStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetStartTime must be specified if op_FltSetStartTime is specified.
             :type val_c_FltSetStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetTimestamp: The operator to apply to the field FltSetTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetTimestamp: If op_FltSetTimestamp is specified, the field named in this input will be compared to the value in FltSetTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetTimestamp must be specified if op_FltSetTimestamp is specified.
             :type val_f_FltSetTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetTimestamp: If op_FltSetTimestamp is specified, this value will be compared to the value in FltSetTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetTimestamp must be specified if op_FltSetTimestamp is specified.
             :type val_c_FltSetTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FltSetUseCount: The operator to apply to the field FltSetUseCount. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FltSetUseCount: The number of usage of this rule list inside the configuration (may be for filtering or for NAT, vpn etc). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FltSetUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FltSetUseCount: If op_FltSetUseCount is specified, the field named in this input will be compared to the value in FltSetUseCount using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FltSetUseCount must be specified if op_FltSetUseCount is specified.
             :type val_f_FltSetUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FltSetUseCount: If op_FltSetUseCount is specified, this value will be compared to the value in FltSetUseCount using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FltSetUseCount must be specified if op_FltSetUseCount is specified.
             :type val_c_FltSetUseCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device filter sets as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device filter set methods. The listed methods will be called on each device filter set returned and included in the output. Available methods are: data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFilterSetID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFilterSetID. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFilterSet. Valid values are DeviceFilterSetID, DeviceID, DataSourceID, FltSetFirstSeenTime, FltSetStartTime, FltSetEndTime, FltSetTimestamp, FltSetChangedCols, FltSetName, FltSetIPVersion, FltSetUseCount, FltSetArtificialInd, FltSetConfigText, FltSetProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_filter_sets: An array of the DeviceFilterSet objects that match the specified input criteria.
             :rtype device_filter_sets: Array of DeviceFilterSet

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFilterSetID: The internal NetMRI identifier for this rule list.
             :type DeviceFilterSetID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFilterSetID: The internal NetMRI identifier for this rule list.
             :type DeviceFilterSetID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..remote import RemoteModel


class DeviceViewerEpgGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``tenant_name:`` none
    |  ``attribute type:`` string

    |  ``tenant_dn:`` none
    |  ``attribute type:`` string

    |  ``app_profile_name:`` none
    |  ``attribute type:`` string

    |  ``app_profile_dn:`` none
    |  ``attribute type:`` string

    |  ``epg_name:`` none
    |  ``attribute type:`` string

    |  ``epg_dn:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "tenant_name",
                  "tenant_dn",
                  "app_profile_name",
                  "app_profile_dn",
                  "epg_name",
                  "epg_dn",
                  )



from ..remote import RemoteModel


class IfSettingRemote(RemoteModel):
    """
    This table list out the interface settings.


    |  ``CollectionInd:`` A flag indicating if data collection enabled on this interface.
    |  ``attribute type:`` bool

    |  ``created_at:`` The date and time the record was initially created in NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the record was last modified in NetMRI.
    |  ``attribute type:`` datetime

    |  ``DeviceID:`` The internal NetMRI identifier for device.
    |  ``attribute type:`` number

    |  ``InterfaceID:`` The internal NetMRI identifier for interface.
    |  ``attribute type:`` number

    |  ``SPMExcludedInd:`` A flag indicating if interface excluded from Switch Port Management.
    |  ``attribute type:`` bool

    |  ``id:`` The internal NetMRI identifier for interface setting.
    |  ``attribute type:`` number

    |  ``ifIndex:`` The index of interface.
    |  ``attribute type:`` number

    """

    properties = ("CollectionInd",
                  "created_at",
                  "updated_at",
                  "DeviceID",
                  "InterfaceID",
                  "SPMExcludedInd",
                  "id",
                  "ifIndex",
                  )



from ..remote import RemoteModel


class CircuitLinkGridRemote(RemoteModel):
    """



    |  ``CLinkID:`` none
    |  ``attribute type:`` string

    |  ``CLinkIndex:`` none
    |  ``attribute type:`` string

    |  ``CLinkIfIndex:`` none
    |  ``attribute type:`` string

    |  ``CLinkOverallState:`` none
    |  ``attribute type:`` string

    |  ``CLinkDTGNumber:`` none
    |  ``attribute type:`` string

    |  ``CLinkTGCNumber:`` none
    |  ``attribute type:`` string

    |  ``CLinkNodeType:`` none
    |  ``attribute type:`` string

    |  ``CLinkTransmissionType:`` none
    |  ``attribute type:`` string

    |  ``CLinkParentID:`` none
    |  ``attribute type:`` string

    |  ``CLinkSwitchCode:`` none
    |  ``attribute type:`` string

    """

    properties = ("CLinkID",
                  "CLinkIndex",
                  "CLinkIfIndex",
                  "CLinkOverallState",
                  "CLinkDTGNumber",
                  "CLinkTGCNumber",
                  "CLinkNodeType",
                  "CLinkTransmissionType",
                  "CLinkParentID",
                  "CLinkSwitchCode",
                  )



from ..remote import RemoteModel


class AccessChangeProposalGridRemote(RemoteModel):
    """
    list of proposals computed for an access change task (provisioing)


    |  ``id:`` The internal NetMRI identifier for this provisioning proposal.
    |  ``attribute type:`` number

    |  ``Network:`` The name of the Network View associated.
    |  ``attribute type:`` string

    |  ``DeviceID:`` The internal NetMRI identifier for the device on which will be applied this proposal.
    |  ``attribute type:`` number

    |  ``ProposalID:`` The internal NetMRI identifier for this provision operation.
    |  ``attribute type:`` string

    |  ``DeviceType:`` The NetMRI-determined device type.
    |  ``attribute type:`` string

    |  ``DeviceAssurance:`` The assurance level of the device type value.
    |  ``attribute type:`` number

    |  ``DeviceName:`` The NetMRI name of the device.
    |  ``attribute type:`` string

    |  ``DeviceIPDotted:`` The management IP address of the device, in dotted (or colon-delimited for IPv6) format.
    |  ``attribute type:`` string

    |  ``DeviceIPNumeric:`` The numerical value of the device IP address.
    |  ``attribute type:`` number

    |  ``DeviceFilterSetID:`` The internal NetMRI identifier for the rule list against which was processed this elementary search.
    |  ``attribute type:`` string

    |  ``DeviceFilterSetName:`` The name of the rule list.
    |  ``attribute type:`` string

    |  ``RuleNum:`` If proposal is for adding a rule, the order of this rule within the rule list.
    |  ``attribute type:`` string

    |  ``RuleNumEditableInd:`` A flag indicating if the order of rule to add, in the rule list is editable.
    |  ``attribute type:`` bool

    |  ``SrcObjID:`` The internal NetMRI Identifier of the network object associated with this proposal (as source element if adding a rule). Value -1 if it is a new object, not already defined in the database.
    |  ``attribute type:`` number

    |  ``SrcObjName:`` The name of the network object associated as source element to the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``SrcMatchedObjNames:`` An array of available network object that can be used to define the source element of the new rule of this proposal. Each row of this array contains a couple : internal NetMRI identifier of the object, name of the object
    |  ``attribute type:`` string

    |  ``SrcObjSummary:`` A summary text for the expected value for this source element of the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``SrcObjEditableInd:`` A flag indicating that the  source element of this rule can be associated with a new object.
    |  ``attribute type:`` bool

    |  ``SrcObjHasDetailInd:`` A flag indicating that the summary has been shorten, thus more detail is available for the source network object for this rule.
    |  ``attribute type:`` bool

    |  ``DestObjID:`` The internal NetMRI Identifier of the network object associated with this proposal as destination element of the adding rule. Value -1 if it is a new object, not already defined in the database.
    |  ``attribute type:`` number

    |  ``DestObjName:`` The name of the network object associated as destination to the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``DestMatchedObjNames:`` An array of available network object that can be used to define the destination element of the new rule of this proposal. Each row of this array contains a couple : internal NetMRI identifier of the object, name of the object.
    |  ``attribute type:`` string

    |  ``DestObjSummary:`` A summary text for the expected value for this destination element of the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``DestObjEditableInd:`` A flag indicating that the  destination element of this rule can be associated with a new object.
    |  ``attribute type:`` bool

    |  ``DestObjHasDetailInd:`` A flag indicating that the summary has been shorten, thus more detail is available for the destination network object for this rule.
    |  ``attribute type:`` bool

    |  ``SvcID:`` The internal NetMRI Identifier of the service object associated with this proposal for the adding rule. Value -1 if it is a new service not already defined in the database.
    |  ``attribute type:`` number

    |  ``SvcName:`` The name of the service object associated to the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``SvcMatchedObjNames:`` An array of available service objects that can be used to define the service element of the new rule of this proposal. Each row of this array contains a couple : internal NetMRI identifier of the service, name of the service.
    |  ``attribute type:`` string

    |  ``SvcSummary:`` A summary text for the expected value for this destination element of the rule involved in this proposal.
    |  ``attribute type:`` string

    |  ``SvcEditableInd:`` A flag indicating that the  service element of this rule can be associated with a new service.
    |  ``attribute type:`` bool

    |  ``SvcHasDetailInd:`` A flag indicating that the summary has been shorten, thus more detail is available for the service object for this rule.
    |  ``attribute type:`` bool

    |  ``SrcSvcName:`` Unused
    |  ``attribute type:`` string

    |  ``Action:`` Action that proposal will apply on the configuration: one of 'ADD_FILTER', 'DELETE_FILTER', 'DELETE_OBJECT', 'DELETE_SERVICE', 'DELETE_FILTER_SET'.
    |  ``attribute type:`` string

    |  ``Warning:`` An indication of level of warnings from analysis for this proposal. One of : 'OK', 'Warning','Error' .
    |  ``attribute type:`` string

    |  ``WarningMsg:`` The list of warnings and errors thrown by analysis for this proposal.
    |  ``attribute type:`` string

    |  ``ConfigurationDetails:`` The list of device specific commands to apply on the configuration to implement that proposal.
    |  ``attribute type:`` string

    |  ``WarningMsgHasDetailInd:`` A flag indicating that the warning message has been shortened, thus more detail is available for the whole list of warnings or errors
    |  ``attribute type:`` bool

    |  ``SrcGroupTag:`` A group indicator for all source fields able to share the same selection: all fields of same group are synchronized.
    |  ``attribute type:`` string

    |  ``DestGroupTag:`` A group indicator for all destination fields able to share the same selectionDestGroupTag.
    |  ``attribute type:`` string

    |  ``SvcGroupTag:`` A group indicator for all service fields able to share the same selectionSvcGroupTag.
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` The internal identifier for the network which the device is associated to.
    |  ``attribute type:`` number

    """

    properties = ("id",
                  "Network",
                  "DeviceID",
                  "ProposalID",
                  "DeviceType",
                  "DeviceAssurance",
                  "DeviceName",
                  "DeviceIPDotted",
                  "DeviceIPNumeric",
                  "DeviceFilterSetID",
                  "DeviceFilterSetName",
                  "RuleNum",
                  "RuleNumEditableInd",
                  "SrcObjID",
                  "SrcObjName",
                  "SrcMatchedObjNames",
                  "SrcObjSummary",
                  "SrcObjEditableInd",
                  "SrcObjHasDetailInd",
                  "DestObjID",
                  "DestObjName",
                  "DestMatchedObjNames",
                  "DestObjSummary",
                  "DestObjEditableInd",
                  "DestObjHasDetailInd",
                  "SvcID",
                  "SvcName",
                  "SvcMatchedObjNames",
                  "SvcSummary",
                  "SvcEditableInd",
                  "SvcHasDetailInd",
                  "SrcSvcName",
                  "Action",
                  "Warning",
                  "WarningMsg",
                  "ConfigurationDetails",
                  "WarningMsgHasDetailInd",
                  "SrcGroupTag",
                  "DestGroupTag",
                  "SvcGroupTag",
                  "VirtualNetworkID",
                  )



from ..remote import RemoteModel


class TaeIssuesAndApprovalsGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``Time:`` none
    |  ``attribute type:`` string

    |  ``Type:`` none
    |  ``attribute type:`` string

    |  ``Severity:`` none
    |  ``attribute type:`` string

    |  ``SeverityID:`` none
    |  ``attribute type:`` string

    |  ``Name:`` none
    |  ``attribute type:`` string

    |  ``DeviceNumber:`` none
    |  ``attribute type:`` string

    |  ``Action:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "Time",
                  "Type",
                  "Severity",
                  "SeverityID",
                  "Name",
                  "DeviceNumber",
                  "Action",
                  )



from ..remote import RemoteModel


class AuthUserRemote(RemoteModel):
    """
    The defined NetMRI users.


    |  ``id:`` The internal NetMRI identifier for this user.
    |  ``attribute type:`` number

    |  ``user_name:`` The user's login name.
    |  ``attribute type:`` string

    |  ``password:`` The user's password (required for local authentication).
    |  ``attribute type:`` string

    |  ``email:`` The user's email address.
    |  ``attribute type:`` string

    |  ``notes:`` Notes on the user, as entered by the administrator.
    |  ``attribute type:`` string

    |  ``created_at:`` The date and time the record was initially created in NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the record was last modified in NetMRI.
    |  ``attribute type:`` datetime

    |  ``first_name:`` The user's first name.
    |  ``attribute type:`` string

    |  ``last_name:`` The user's last name.
    |  ``attribute type:`` string

    |  ``is_system:`` A flag indicating whether this is a built-in user. Built-in users cannot be removed.
    |  ``attribute type:`` number

    |  ``last_login:`` The date and time this use last logged into the NetMRI.
    |  ``attribute type:`` datetime

    |  ``expiration:`` The expiration date for this user's password.
    |  ``attribute type:`` datetime

    |  ``consecutive_failed_logins:`` The number of failed logins since the last successful login.
    |  ``attribute type:`` number

    |  ``account_locked:`` A flag indicating whether or not this account is locked due to failed login attempts.
    |  ``attribute type:`` number

    |  ``account_locked_date:`` The date and time that the user's account was locked.
    |  ``attribute type:`` datetime

    |  ``account_disabled:`` A flag indicating whether this user's account has been administratively disabled.
    |  ``attribute type:`` number

    |  ``account_disabled_date:`` The date and time that the user's account was disabled.
    |  ``attribute type:`` datetime

    |  ``cli_creds_enabled_ind:`` A flag indicating whether or not to use this user's individual CLI credentials for device interaction.
    |  ``attribute type:`` bool

    |  ``password_secure:`` Internal representation of password
    |  ``attribute type:`` string

    |  ``password_version:`` version of encryption used to encrypt password
    |  ``attribute type:`` number

    |  ``cli_user_name_secure:`` The user's network device user name.
    |  ``attribute type:`` string

    |  ``cli_password_secure:`` The user's network device password.
    |  ``attribute type:`` string

    |  ``cli_enable_password_secure:`` The user's network device privileged mode password.
    |  ``attribute type:`` string

    |  ``secure_version:`` The encryption version of the username and passwords.
    |  ``attribute type:`` number

    |  ``auth_service_id:`` The id of the last authentication service where this user was authenticated.
    |  ``attribute type:`` number

    |  ``force_local_ind:`` A flag indicating whether user is forced to use local authorisation or not.
    |  ``attribute type:`` bool

    |  ``last_local_authz_ind:`` The source where the last authorization came from. May be 0 - Remote, 1 - Local, 2 - Forced Local
    |  ``attribute type:`` number

    |  ``cert:`` Client Certificate stored on clinet success authorization when CAC is enabled
    |  ``attribute type:`` string

    |  ``db_username:`` Username for MySQL Database.
    |  ``attribute type:`` string

    |  ``db_password_secure:`` Password for MySQL Database.
    |  ``attribute type:`` string

    |  ``db_creds_enabled_ind:`` A flag which indicates that the user has database credentials enabled.
    |  ``attribute type:`` bool

    """

    properties = ("id",
                  "user_name",
                  "password",
                  "email",
                  "notes",
                  "created_at",
                  "updated_at",
                  "first_name",
                  "last_name",
                  "is_system",
                  "last_login",
                  "expiration",
                  "consecutive_failed_logins",
                  "account_locked",
                  "account_locked_date",
                  "account_disabled",
                  "account_disabled_date",
                  "cli_creds_enabled_ind",
                  "password_secure",
                  "password_version",
                  "cli_user_name_secure",
                  "cli_password_secure",
                  "cli_enable_password_secure",
                  "secure_version",
                  "auth_service_id",
                  "force_local_ind",
                  "last_local_authz_ind",
                  "cert",
                  "db_username",
                  "db_password_secure",
                  "db_creds_enabled_ind",
                  )



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class RoutingAreaRemote(RemoteModel):
    """
    This model captures the OSPF routing areas as well as the BGP and EIGRP autonomous systems identified as running on or connected to the network.


    |  ``EigrpVpnIndex:`` The SNMP index of the VRF to which this routing area belongs.
    |  ``attribute type:`` number

    |  ``RoutingAreaChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``RoutingAreaEndTime:`` The ending effective time of this revision of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``RoutingAreaID:`` The internal NetMRI identifier for the routing area or autonomous system.
    |  ``attribute type:`` number

    |  ``RoutingAreaName:`` For OSPF, the dotted version of the Area ID. For other protocols, the AS.
    |  ``attribute type:`` string

    |  ``RoutingAreaNumber:`` The numerical OSPF Area ID, BGP AS or EIGRP AS.
    |  ``attribute type:`` number

    |  ``RoutingAreaStartTime:`` The starting effective time of this revision of the record.
    |  ``attribute type:`` datetime

    |  ``RoutingAreaTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``RoutingAreaType:`` OSPF, BGP, or EIGRP.
    |  ``attribute type:`` string


    """

    properties = ("EigrpVpnIndex",
                  "RoutingAreaChangedCols",
                  "RoutingAreaEndTime",
                  "RoutingAreaID",
                  "RoutingAreaName",
                  "RoutingAreaNumber",
                  "RoutingAreaStartTime",
                  "RoutingAreaTimestamp",
                  "RoutingAreaType",
                  )

    @property
    @check_api_availability
    def data_source(self):
        """
        The collector NetMRI that collected this data record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"RoutingAreaID": self.RoutingAreaID})
